@@ -12,7 +12,7 @@ mkdir -p $TMPDIR/lib
 
 grep -i xstatic requirements.txt > $TMPDIR/requirements.txt
 
-pip install --system -t $TMPDIR/lib -r $TMPDIR/requirements.txt -c https://git.openstack.org/cgit/openstack/requirements/plain/upper-constraints.txt
+pip3 install --system -t $TMPDIR/lib -r $TMPDIR/requirements.txt -c https://git.openstack.org/cgit/openstack/requirements/plain/upper-constraints.txt
 
 (
     cd $TMPDIR/lib
@@ -24,6 +24,5 @@ pip install --system -t $TMPDIR/lib -r $TMPDIR/requirements.txt -c https://git.o
     tar -czf horizon_${version}.orig-xstatic.tar.gz *
 )
 
-mkdir -p ../build-area
-mv  $TMPDIR/lib/horizon_${version}.orig-xstatic.tar.gz ../build-area
+mv  $TMPDIR/lib/horizon_${version}.orig-xstatic.tar.gz ../
 rm -rf $TMPDIR
